@@ -1,8 +1,3 @@
-#' Example data set
-#'
-#'
-"pbmc_small"
-
 #' Example data set 2
 #'
 #'
