@@ -4,6 +4,13 @@
 	
 	msg = paste0("========================================
 ", pkgname, " version ", version, "
+If you use TIDYSEURAT in published research, please cite:
+
+Mangiola et al. Interfacing Seurat with the R tidy universe. Bioinformatics 2021.
+
+This message can be suppressed by:
+  suppressPackageStartupMessages(library(tidyseurat))
+  
 To restore the Seurat default display use options(\"restore_Seurat_show\" = TRUE) 
 ========================================
 ")	
