@@ -27,7 +27,7 @@ library(Seurat)
 library(tidyseurat)
 
 ## -----------------------------------------------------------------------------
-data("pbmc_small")
+pbmc_small = SeuratObject::pbmc_small
 
 ## -----------------------------------------------------------------------------
 pbmc_small
@@ -75,7 +75,7 @@ pbmc_small %>%
 ## -----------------------------------------------------------------------------
 pbmc_small %>%
   join_features(features = c("HLA-DRA", "LYZ")) %>%
-  ggplot(aes(groups, abundance_RNA + 1, fill = groups)) +
+  ggplot(aes(groups, .abundance_RNA + 1, fill = groups)) +
   geom_boxplot(outlier.shape = NA) +
   geom_jitter(aes(size = nCount_RNA), alpha = 0.5, width = 0.2) +
   scale_y_log10() +
@@ -113,7 +113,8 @@ pbmc_small_cluster %>%
 #  # Identify top 10 markers per cluster
 #  markers <-
 #    pbmc_small_cluster %>%
-#    FindAllMarkers(only.pos = TRUE, min.pct = 0.25, thresh.use = 0.25) %>%
+#    mutate(orig.ident = seurat_clusters) %>%
+#    FindAllMarkers(only.pos = TRUE) %>%
 #    group_by(cluster) %>%
 #    top_n(10, avg_logFC)
 #  
@@ -124,25 +125,25 @@ pbmc_small_cluster %>%
 #      group.colors = friendly_cols
 #    )
 
-## ----markers_v4, eval=(packageVersion("Seurat") >= package_version("4.0.0"))----
-# Identify top 10 markers per cluster
-markers <-
-  pbmc_small_cluster %>%
-  FindAllMarkers(only.pos = TRUE, min.pct = 0.25, thresh.use = 0.25) %>%
-  group_by(cluster) %>%
-  top_n(10, avg_log2FC)
+## ----markers_v4, eval=FALSE---------------------------------------------------
+#  # Identify top 10 markers per cluster
+#  markers <-
+#    pbmc_small_cluster %>%
+#    FindAllMarkers(only.pos = TRUE, min.pct = 0.25, thresh.use = 0.25) %>%
+#    group_by(cluster) %>%
+#    top_n(10, avg_log2FC)
+#  
+#  # Plot heatmap
+#  pbmc_small_cluster %>%
+#    DoHeatmap(
+#      features = markers$gene,
+#      group.colors = friendly_cols
+#    )
 
-# Plot heatmap
-pbmc_small_cluster %>%
-  DoHeatmap(
-    features = markers$gene,
-    group.colors = friendly_cols
-  )
-
-## ----umap---------------------------------------------------------------------
-pbmc_small_UMAP <-
-  pbmc_small_cluster %>%
-  RunUMAP(reduction = "pca", dims = 1:15, n.components = 3L, )
+## ----umap, eval=FALSE---------------------------------------------------------
+#  pbmc_small_UMAP <-
+#    pbmc_small_cluster %>%
+#    RunUMAP(reduction = "pca", dims = 1:15, n.components = 3L)
 
 ## ----umap plot, eval=FALSE----------------------------------------------------
 #  pbmc_small_UMAP %>%
@@ -172,88 +173,88 @@ pbmc_small_UMAP <-
 #    as_tibble(rownames = "cell") %>%
 #    select(cell, first.labels)
 
-## -----------------------------------------------------------------------------
-# Join UMAP and cell type info
-pbmc_small_cell_type <-
-  pbmc_small_UMAP %>%
-  left_join(cell_type_df, by = "cell")
+## ---- eval=FALSE--------------------------------------------------------------
+#  # Join UMAP and cell type info
+#  pbmc_small_cell_type <-
+#    pbmc_small_UMAP %>%
+#    left_join(cell_type_df, by = "cell")
+#  
+#  # Reorder columns
+#  pbmc_small_cell_type %>%
+#    tidyseurat::select(cell, first.labels, everything())
 
-# Reorder columns
-pbmc_small_cell_type %>%
-  tidyseurat::select(cell, first.labels, everything())
+## ---- eval=FALSE--------------------------------------------------------------
+#  pbmc_small_cell_type %>%
+#    count(seurat_clusters, first.labels)
 
-## -----------------------------------------------------------------------------
-pbmc_small_cell_type %>%
-  count(seurat_clusters, first.labels)
+## ----eval=FALSE---------------------------------------------------------------
+#  pbmc_small_cell_type %>%
+#  
+#    # Reshape and add classifier column
+#    pivot_longer(
+#      cols = c(seurat_clusters, first.labels),
+#      names_to = "classifier", values_to = "label"
+#    ) %>%
+#  
+#    # UMAP plots for cell type and cluster
+#    ggplot(aes(UMAP_1, UMAP_2, color = label)) +
+#    geom_point() +
+#    facet_wrap(~classifier) +
+#    my_theme
 
-## -----------------------------------------------------------------------------
-pbmc_small_cell_type %>%
+## ----eval=FALSE---------------------------------------------------------------
+#  pbmc_small_cell_type %>%
+#  
+#    # Add some mitochondrial abundance values
+#    mutate(mitochondrial = rnorm(n())) %>%
+#  
+#    # Plot correlation
+#    join_features(features = c("CST3", "LYZ"), shape = "wide") %>%
+#    ggplot(aes(CST3 + 1, LYZ + 1, color = groups, size = mitochondrial)) +
+#    geom_point() +
+#    facet_wrap(~first.labels, scales = "free") +
+#    scale_x_log10() +
+#    scale_y_log10() +
+#    my_theme
 
-  # Reshape and add classifier column
-  pivot_longer(
-    cols = c(seurat_clusters, first.labels),
-    names_to = "classifier", values_to = "label"
-  ) %>%
+## ----eval=FALSE---------------------------------------------------------------
+#  pbmc_small_nested <-
+#    pbmc_small_cell_type %>%
+#    filter(first.labels != "Erythrocytes") %>%
+#    mutate(cell_class = if_else(`first.labels` %in% c("Macrophages", "Monocytes"), "myeloid", "lymphoid")) %>%
+#    nest(data = -cell_class)
+#  
+#  pbmc_small_nested
 
-  # UMAP plots for cell type and cluster
-  ggplot(aes(UMAP_1, UMAP_2, color = label)) +
-  geom_point() +
-  facet_wrap(~classifier) +
-  my_theme
+## ----eval=FALSE---------------------------------------------------------------
+#  pbmc_small_nested_reanalysed <-
+#    pbmc_small_nested %>%
+#    mutate(data = map(
+#      data, ~ .x %>%
+#        FindVariableFeatures(verbose = FALSE) %>%
+#        RunPCA(npcs = 10, verbose = FALSE) %>%
+#        FindNeighbors(verbose = FALSE) %>%
+#        FindClusters(method = "igraph", verbose = FALSE) %>%
+#        RunUMAP(reduction = "pca", dims = 1:10, n.components = 3L, verbose = FALSE)
+#    ))
+#  
+#  pbmc_small_nested_reanalysed
 
-## -----------------------------------------------------------------------------
-pbmc_small_cell_type %>%
-
-  # Add some mitochondrial abundance values
-  mutate(mitochondrial = rnorm(n())) %>%
-
-  # Plot correlation
-  join_features(features = c("CST3", "LYZ"), shape = "wide") %>%
-  ggplot(aes(CST3 + 1, LYZ + 1, color = groups, size = mitochondrial)) +
-  geom_point() +
-  facet_wrap(~first.labels, scales = "free") +
-  scale_x_log10() +
-  scale_y_log10() +
-  my_theme
-
-## -----------------------------------------------------------------------------
-pbmc_small_nested <-
-  pbmc_small_cell_type %>%
-  filter(first.labels != "Erythrocytes") %>%
-  mutate(cell_class = if_else(`first.labels` %in% c("Macrophages", "Monocytes"), "myeloid", "lymphoid")) %>%
-  nest(data = -cell_class)
-
-pbmc_small_nested
-
-## -----------------------------------------------------------------------------
-pbmc_small_nested_reanalysed <-
-  pbmc_small_nested %>%
-  mutate(data = map(
-    data, ~ .x %>%
-      FindVariableFeatures(verbose = FALSE) %>%
-      RunPCA(npcs = 10, verbose = FALSE) %>%
-      FindNeighbors(verbose = FALSE) %>%
-      FindClusters(method = "igraph", verbose = FALSE) %>%
-      RunUMAP(reduction = "pca", dims = 1:10, n.components = 3L, verbose = FALSE)
-  ))
-
-pbmc_small_nested_reanalysed
-
-## -----------------------------------------------------------------------------
-pbmc_small_nested_reanalysed %>%
-
-  # Convert to tibble otherwise Seurat drops reduced dimensions when unifying data sets.
-  mutate(data = map(data, ~ .x %>% as_tibble())) %>%
-  unnest(data) %>%
-
-  # Define unique clusters
-  unite("cluster", c(cell_class, seurat_clusters), remove = FALSE) %>%
-
-  # Plotting
-  ggplot(aes(UMAP_1, UMAP_2, color = cluster)) +
-  geom_point() +
-  facet_wrap(~cell_class) +
-  my_theme
+## ----eval=FALSE---------------------------------------------------------------
+#  pbmc_small_nested_reanalysed %>%
+#  
+#    # Convert to tibble otherwise Seurat drops reduced dimensions when unifying data sets.
+#    mutate(data = map(data, ~ .x %>% as_tibble())) %>%
+#    unnest(data) %>%
+#  
+#    # Define unique clusters
+#    unite("cluster", c(cell_class, seurat_clusters), remove = FALSE) %>%
+#  
+#    # Plotting
+#    ggplot(aes(UMAP_1, UMAP_2, color = cluster)) +
+#    geom_point() +
+#    facet_wrap(~cell_class) +
+#    my_theme
 
 ## -----------------------------------------------------------------------------
 sessionInfo()
